==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/util/StandaloneLocator.h <==
// public final class gnu.xml.libxmlj.util.StandaloneLocator

// class file dependencies
// @dep_class 76af128acb5f73bc gnu_xml_libxmlj_util_StandaloneLocator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_
#define _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$refs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$refs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object	_jc_gnu_xml_libxmlj_util_StandaloneLocator$object;

typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$_init$fac5b8a67c08ce03(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
extern jint _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods	gnu_xml_libxmlj_util_StandaloneLocator;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs {
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$refs {
    _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs	gnu_xml_libxmlj_util_StandaloneLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs {
	jint	lineNumber;
	jint	columnNumber;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs	gnu_xml_libxmlj_util_StandaloneLocator;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object {
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype _jc_gnu_xml_libxmlj_util_StandaloneLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_StandaloneLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_StandaloneLocator$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/util/StandaloneLocator.h <==
// public final class gnu.xml.libxmlj.util.StandaloneLocator

// class file dependencies
// @dep_class 76af128acb5f73bc gnu_xml_libxmlj_util_StandaloneLocator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_
#define _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$refs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$refs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs	_jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object	_jc_gnu_xml_libxmlj_util_StandaloneLocator$object;

typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$_init$fac5b8a67c08ce03(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_StandaloneLocator$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_util_StandaloneLocator$method_info$getSystemId$dfda7e64149e1929;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vmethods	gnu_xml_libxmlj_util_StandaloneLocator;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs {
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$refs {
    _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_refs	gnu_xml_libxmlj_util_StandaloneLocator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs {
	jint	lineNumber;
	jint	columnNumber;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_StandaloneLocator$sub_nonrefs	gnu_xml_libxmlj_util_StandaloneLocator;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_StandaloneLocator$object {
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_StandaloneLocator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_StandaloneLocator$vtype _jc_gnu_xml_libxmlj_util_StandaloneLocator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_StandaloneLocator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_StandaloneLocator$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_StandaloneLocator_H_ */
